@@ -373,13 +373,17 @@ def copySettings(data: dict=None)->object:
         obj['default_value'] = data['attributes']['default_value']
         obj['clean_text'] = data['attributes']['clean_text']
         obj['extension'] = data['relationships']['extension']['data']
+        obj['enabled'] = data['attributes']['enabled']
     elif data['type'] == 'rules':
         obj['name'] = data['attributes']['name']
+        obj['enabled'] = data['attributes']['enabled']
     elif data['type'] == 'rule_components':
         obj['name'] = data['attributes']['name']
         obj['order'] = data['attributes']['order']
         obj['descriptor'] = data['attributes']['delegate_descriptor_id']
         obj['negate'] = data['attributes']['negate']
+        obj['delay_next'] = data['attributes']['delay_next']
+        obj['timeout'] = data['attributes']['timeout']
         obj['rule_order'] = data['attributes']['rule_order']
         obj['settings'] = data['attributes']['settings']
         obj['extension'] = data['relationships']['extension']['data']
