@@ -247,18 +247,21 @@ class Property:
             data = rules
         return data
 
-    def searchRules(self, name: str = None, enabled: bool = None, published: bool = None, dirty: bool = None, verbose:bool = False, **kwargs)->object:
+    def searchRules(self, name: str = None,name_contains:str=None, enabled: bool = None, published: bool = None, dirty: bool = None, verbose:bool = False, **kwargs)->object:
         """
         Returns the rules searched through the different operator. One argument is required in order to return a result. 
         Arguments: 
-            name : OPTIONAL : string of what is searched (used as "contains")
+            name : OPTIONAL : string of what is searched (used as "EQUALS")
+            name_contains : OPTIONAL : string of what is searched (used as "CONTAINS")
             enabled : OPTIONAL : boolean if search for enabled rules or not
             published : OPTIONAL : boolean if search for published rules or not
             dirty : OPTIONAL : boolean if search for dirty rules or not
         """
         filters = {}
         if name != None:
-            filters['filter[name]=CONTAINS '] = f"CONTAINS {name}"
+            filters['filter[name]=CONTAINS '] = f"EQ {name}"
+        if name_contains != None:
+            filters['filter[name]=CONTAINS '] = f"CONTAINS {name_contains}"
         if dirty != None:
             filters['filter[dirty]'] = f"EQ {str(dirty).lower()}"
         if enabled != None:
@@ -532,6 +535,8 @@ class Property:
             settings : REQUIRED: string that define the setting to set in the extension. Usually, it can be empty.
             delegate_descriptor_id : REQUIRED : delegate descriptor id (set in name)
         """
+        if extension_id is None:
+            raise ValueError("Require an extension ID")
         obj = {
             "data": {
                 "attributes": {
@@ -563,7 +568,8 @@ class Property:
         Arguments:
             name : REQUIRED : name of your rule. 
         """
-
+        if name is None:
+            raise ValueError("Require a name for the rule")
         obj = {
             "data": {
                 "attributes": {
@@ -594,8 +600,18 @@ class Property:
             (can be found from translator)
             settings : OPTIONAL : settings for that rule component
         possible kwargs:
-            order : the order of the rule component        
+            order : the order of the rule component
+            negate : if the component is a negation
+            rule_order : the priority of the rule
+            timeout : the associated timeout with the rule component
+            delay_next : if we should delay the next action
         """
+        if name is None:
+            raise ValueError("A name must be specified")
+        if descriptor is None:
+            raise ValueError("A delegate_descriptor_id must be specified in the descriptor argument")
+        if extension_infos is None:
+            raise ValueError("Extension configuration should be provided")
         obj = {
             "data": {
                 "attributes": {
@@ -615,6 +631,14 @@ class Property:
             obj['data']['attributes']['settings'] = settings
         if 'order' in kwargs:
             obj['data']['attributes']['order'] = kwargs.get('order')
+        if 'rule_order' in kwargs:
+            obj['data']['attributes']['rule_order'] = kwargs.get('rule_order')
+        if 'negate' in kwargs:
+            obj['data']['attributes']['negate'] = kwargs.get('negate')
+        if 'delay_next' in kwargs:
+            obj['data']['attributes']['delay_next'] = kwargs.get('delay_next')
+        if 'timeout' in kwargs:
+            obj['data']['attributes']['timeout'] = kwargs.get('timeout')
         rc = self.connector.postData(self._RuleComponents, data=obj)
         try:
             data = rc['data']
@@ -622,7 +646,7 @@ class Property:
             data = rc
         return data
 
-    def createDataElement(self, name: str, settings: str = None, descriptor: str = None, extension: dict = None, **kwargs: dict)->object:
+    def createDataElement(self, name: str, descriptor: str = None, settings: str = None, extension: dict = None, **kwargs: dict)->object:
         """
         Create Data Elements following the usage of required arguments. 
         Arguments: 
@@ -630,7 +654,13 @@ class Property:
             descriptor : REQUIRED : delegate_descriptor_id for the data element
             extension : REQUIRED : extension id used for the data element. (dictionary)
             settings : OPTIONAL : settings for the data element
+        possible kwargs:
+            any attributes key you want to set.
         """
+        if name is None:
+            raise ValueError("Require a name")
+        if descriptor is None:
+            raise ValueError("Require a delegate_descriptor_id")
         obj = {
             "data": {
                 "attributes": {
@@ -646,11 +676,10 @@ class Property:
                 "type": "data_elements"
             }
         }
-        try:
-            if settings is not None:
-                obj['data']['attributes']['settings'] = settings
-        except:
-            pass
+        if settings is not None:
+            obj['data']['attributes']['settings'] = settings
+        for kwarg in kwargs:
+            obj['data']['attributes'][kwarg] = kwargs[kwarg]
         dataElements = self.connector.postData(self._DataElement, data=obj)
         try:
             data = dataElements['data']
@@ -756,7 +785,7 @@ class Property:
         except:
             return lib
 
-    def reviseExtensions(self, extension_id, attr_dict: dict, **kwargs)-> object:
+    def reviseExtension(self, extension_id, attr_dict: dict, **kwargs)-> object:
         """
         update the extension with the information provided in the argument.
         argument: 
@@ -778,7 +807,7 @@ class Property:
         data = extensions['data']
         return data
 
-    def reviseRules(self, rule_id: str)->object:
+    def reviseRule(self, rule_id: str)->object:
         """
         Update the rule.
         arguments: 
@@ -836,9 +865,25 @@ class Property:
                 lastPage=True
         return data
 
+    def getLatestPublishedVersion(self,revisions:list=None)->dict:
+        """
+        Find the latest published version of a component based on the list of revisions retrieved via getRevisions methods.
+        Arguments:
+            revisions : REQUIRED : list of revisions
+        """
+        if revisions is None:
+            raise ValueError('Require a list of revisions')
+        publishedIndexVersions:dict = {index:rev['attributes']['revision_number'] for index, rev in enumerate(revisions) if rev['attributes']['published'] == True}
+        if len(publishedIndexVersions) == 0:
+            raise IndexError("You want to retrieve a published version of the component.\nBut no published version can be found. Please check if your component has been published")
+        if 0 in list(publishedIndexVersions.values()):
+            return revisions[0]
+        else:
+            maxRevisionIndex = [index for index,value in publishedIndexVersions.items() if value == max(list(publishedIndexVersions.values()))][0]
+            return revisions[maxRevisionIndex]
 
 
-    def reviseDataElements(self, dataElement_id: str)->dict:
+    def reviseDataElement(self, dataElement_id: str)->dict:
         """
         Update the data element information based on the information provided.
         arguments: 
@@ -875,7 +920,7 @@ class Property:
             self.endpoint+path)
         return rule
 
-    def updateRule(self, rule_id: str, attr_dict: object)->object:
+    def updateRule(self, rule_id: str, attr_dict: dict)->dict:
         """
         Update the rule based on elements passed in attr_dict. 
         arguments: 
@@ -883,26 +928,25 @@ class Property:
             attr_dict : REQUIRED : dictionary that will be passed to Launch for update
         documentation : https://developer.adobelaunch.com/api/reference/1.0/rules/update/
         """
+        if rule_id is None:
+            raise ValueError('Require a rule ID')
         obj = {
             "data": {
                 "attributes": attr_dict,
-                "meta": {
-                    "action": "revise"
-                },
                 "id": rule_id,
                 "type": "rules"
             }
         }
-        path = '/rules/'+rule_id
-        rules = self.connector.patchData(
+        path = f'/rules/{rule_id}'
+        res = self.connector.patchData(
             self.endpoint+path, data=obj)
         try:
-            data = rules['data']
+            data = res['data']
         except:
-            data = rules
+            data = res
         return data
 
-    def updateRuleComponent(self, rc_id: str, attr_dict: object, **kwargs)->object:
+    def updateRuleComponent(self, rc_id: str, attr_dict: dict, **kwargs)->dict:
         """
         Update the ruleComponents based on the information provided.
         arguments: 
